@@ -1,5 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
+"""
+Doctest extension to compare floating-point numbers
+"""
 
 # Python 2.7 Standard Library
 import doctest
@@ -7,14 +10,15 @@ import re
 import sys
 import StringIO
 import tokenize
+
 # Third-Party Libraries
 import numpy
 
 
-__author__ = u"Sébastien Boisgérault <Sebastien.Boisgerault@mines-paristech.fr>"
-__version__ = "1.0.2"
+__author__  = u"Sébastien Boisgérault <Sebastien.Boisgerault@mines-paristech.fr>"
+__version__ = "1.1.1"
 __license__ = "MIT License"
-
+__url__     = "https://github.com/boisgera/numtest"
 
 _doctest_OutputChecker = doctest.OutputChecker
 
